==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/NumberNotInRangeFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * NumberNotInRange Filter.
 * @property key The field/property in the event based on which you want to filter.
 * @property operatorType The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
 * Expected value is 'NumberNotInRange'.
 * @property values The set of filter values.
 */
public data class NumberNotInRangeFilterArgs(
    public val key: Output<String>? = null,
    public val operatorType: Output<String>,
    public val values: Output<List<List<Double>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs =
        com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .operatorType(operatorType.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0.map({ args0 -> args0.map({ args0 -> args0 }) }) })).build()
}

/**
 * Builder for [NumberNotInRangeFilterArgs].
 */
@PulumiTagMarker
public class NumberNotInRangeFilterArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var operatorType: Output<String>? = null

    private var values: Output<List<List<Double>>>? = null

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("qlkjhyojfrostswp")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberNotInRange'.
     */
    @JvmName("jnuwcjdngumpiamy")
    public suspend fun operatorType(`value`: Output<String>) {
        this.operatorType = value
    }

    /**
     * @param value The set of filter values.
     */
    @JvmName("urptmhhuffwfwkem")
    public suspend fun values(`value`: Output<List<List<Double>>>) {
        this.values = value
    }

    @JvmName("ljdfuffkyrnvrblu")
    public suspend fun values(vararg values: Output<List<Double>>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values The set of filter values.
     */
    @JvmName("cqpjxeqgjabvyhpl")
    public suspend fun values(values: List<Output<List<Double>>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("uicxvljastrbwloj")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberNotInRange'.
     */
    @JvmName("hmotcfoppldunvrm")
    public suspend fun operatorType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operatorType = mapped
    }

    /**
     * @param value The set of filter values.
     */
    @JvmName("pertseqgwddhymil")
    public suspend fun values(`value`: List<List<Double>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values The set of filter values.
     */
    @JvmName("hlgouhtblwdwwkag")
    public suspend fun values(vararg values: List<Double>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): NumberNotInRangeFilterArgs = NumberNotInRangeFilterArgs(
        key = key,
        operatorType = operatorType ?: throw PulumiNullFieldException("operatorType"),
        values = values,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/NumberNotInRangeFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * NumberNotInRange Filter.
 * @property key The field/property in the event based on which you want to filter.
 * @property operatorType The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
 * Expected value is 'NumberNotInRange'.
 * @property values The set of filter values.
 */
public data class NumberNotInRangeFilterArgs(
    public val key: Output<String>? = null,
    public val operatorType: Output<String>,
    public val values: Output<List<List<Double>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs =
        com.pulumi.azurenative.eventgrid.inputs.NumberNotInRangeFilterArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .operatorType(operatorType.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0.map({ args0 -> args0.map({ args0 -> args0 }) }) })).build()
}

/**
 * Builder for [NumberNotInRangeFilterArgs].
 */
@PulumiTagMarker
public class NumberNotInRangeFilterArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var operatorType: Output<String>? = null

    private var values: Output<List<List<Double>>>? = null

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("vqdwanydttslknlm")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberNotInRange'.
     */
    @JvmName("ktftclpyovvijhce")
    public suspend fun operatorType(`value`: Output<String>) {
        this.operatorType = value
    }

    /**
     * @param value The set of filter values.
     */
    @JvmName("yjdjwdqsigmqopgr")
    public suspend fun values(`value`: Output<List<List<Double>>>) {
        this.values = value
    }

    @JvmName("emdlcycpllceonoi")
    public suspend fun values(vararg values: Output<List<Double>>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values The set of filter values.
     */
    @JvmName("dtnmtgyqulnvjllx")
    public suspend fun values(values: List<Output<List<Double>>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("mlsmbgxsxipfbhvp")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberNotInRange'.
     */
    @JvmName("iiwksbfiorhvyesd")
    public suspend fun operatorType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operatorType = mapped
    }

    /**
     * @param value The set of filter values.
     */
    @JvmName("unpargxsporujgte")
    public suspend fun values(`value`: List<List<Double>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values The set of filter values.
     */
    @JvmName("kakftqxosrvjcacv")
    public suspend fun values(vararg values: List<Double>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): NumberNotInRangeFilterArgs = NumberNotInRangeFilterArgs(
        key = key,
        operatorType = operatorType ?: throw PulumiNullFieldException("operatorType"),
        values = values,
    )
}
